<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

if ( ! function_exists( 'travel_master_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Travel Master Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function travel_master_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'travel_master_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'travel_master_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Travel Master Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function travel_master_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'travel_master_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'travel_master_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Travel Master Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function travel_master_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'travel_master_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'travel_master_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Travel Master Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function travel_master_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if slider section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_master_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[slider_content_type]' )->value();
	return travel_master_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[slider_content_type]' )->value();
	return travel_master_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[slider_content_type]' )->value();
	return travel_master_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

function travel_master_pro_is_slider_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[slider_content_type]' )->value();
	return travel_master_pro_is_slider_section_enable( $control ) && ( 'trip' == $content_type );
}

function travel_master_pro_is_slider_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[slider_content_type]' )->value();
	return travel_master_pro_is_slider_section_enable( $control ) && ( 'trip-types' == $content_type );
}

function travel_master_pro_is_slider_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[slider_content_type]' )->value();
	return travel_master_pro_is_slider_section_enable( $control ) && ( 'activity' == $content_type );
}

function travel_master_pro_is_slider_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[slider_content_type]' )->value();
	return travel_master_pro_is_slider_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if featured section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_master_pro_theme_options[featured_section_enable]' )->value() );
}

/**
 * Check if featured section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_featured_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[featured_content_type]' )->value();
	return travel_master_pro_is_featured_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_featured_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[featured_content_type]' )->value();
	return travel_master_pro_is_featured_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured section content type is trip.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_featured_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[featured_content_type]' )->value();
	return travel_master_pro_is_featured_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if featured section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_featured_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[featured_content_type]' )->value();
	return travel_master_pro_is_featured_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured section content type is trip types.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_featured_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[featured_content_type]' )->value();
	return travel_master_pro_is_featured_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if featured section content type is destination.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_featured_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[featured_content_type]' )->value();
	return travel_master_pro_is_featured_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if featured section content type is activity.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_featured_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[featured_content_type]' )->value();
	return travel_master_pro_is_featured_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if popular destination section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_popular_destination_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_master_pro_theme_options[popular_destination_section_enable]' )->value() );
}

/**
 * Check if popular destination section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_popular_destination_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[popular_destination_content_type]' )->value();
	return travel_master_pro_is_popular_destination_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular destination section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_popular_destination_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[popular_destination_content_type]' )->value();
	return travel_master_pro_is_popular_destination_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular destination section content type is trip.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_popular_destination_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[popular_destination_content_type]' )->value();
	return travel_master_pro_is_popular_destination_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if popular destination section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_popular_destination_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[popular_destination_content_type]' )->value();
	return travel_master_pro_is_popular_destination_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular destination section content type is trip types.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_popular_destination_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[popular_destination_content_type]' )->value();
	return travel_master_pro_is_popular_destination_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if popular destination section content type is destination.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_popular_destination_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[popular_destination_content_type]' )->value();
	return travel_master_pro_is_popular_destination_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if popular destination section content type is activity.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_popular_destination_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[popular_destination_content_type]' )->value();
	return travel_master_pro_is_popular_destination_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_master_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[about_content_type]' )->value();
	return travel_master_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[about_content_type]' )->value();
	return travel_master_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[about_content_type]' )->value();
	return travel_master_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if about section wp travel is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_about_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[about_content_type]' )->value();
	return travel_master_pro_is_about_section_enable( $control ) && class_exists( 'WP_Travel' );
}



/**
 * Check if project section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_project_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_master_pro_theme_options[project_section_enable]' )->value() );
}


/**
 * Check if package section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_package_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_master_pro_theme_options[package_section_enable]' )->value() );
}

/**
 * Check if package section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_package_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[package_content_type]' )->value();
	return travel_master_pro_is_package_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if package section content type is trip types.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_package_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[package_content_type]' )->value();
	return travel_master_pro_is_package_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if package section content type is destination.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_package_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[package_content_type]' )->value();
	return travel_master_pro_is_package_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if package section content type is activity.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_package_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[package_content_type]' )->value();
	return travel_master_pro_is_package_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if traveler choice section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_traveler_choice_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_master_pro_theme_options[traveler_choice_section_enable]' )->value() );
}

/**
 * Check if traveler choice section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_traveler_choice_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[traveler_choice_content_type]' )->value();
	return travel_master_pro_is_traveler_choice_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if traveler choice section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_traveler_choice_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[traveler_choice_content_type]' )->value();
	return travel_master_pro_is_traveler_choice_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if traveler choice section content type is trip.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_traveler_choice_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[traveler_choice_content_type]' )->value();
	return travel_master_pro_is_traveler_choice_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if traveler choice section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_traveler_choice_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[traveler_choice_content_type]' )->value();
	return travel_master_pro_is_traveler_choice_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if traveler choice section content type is trip types.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_traveler_choice_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[traveler_choice_content_type]' )->value();
	return travel_master_pro_is_traveler_choice_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if traveler choice section content type is destination.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_traveler_choice_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[traveler_choice_content_type]' )->value();
	return travel_master_pro_is_traveler_choice_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if traveler choice section content type is activity.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_traveler_choice_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[traveler_choice_content_type]' )->value();
	return travel_master_pro_is_traveler_choice_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_master_pro_theme_options[service_section_enable]' )->value() );
}


function travel_master_pro_is_service_section_icon_enable( $control ) {
	$icon = $control->manager->get_setting( 'travel_master_pro_theme_options[service_section_icon_enable]' )->value();
	return travel_master_pro_is_service_section_enable( $control ) && ( true == $icon );
}
/**
 * Check if service section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[service_content_type]' )->value();
	return travel_master_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[service_content_type]' )->value();
	return travel_master_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[service_content_type]' )->value();
	return travel_master_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[service_content_type]' )->value();
	return travel_master_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

function travel_master_pro_is_service_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[service_content_type]' )->value();
	return travel_master_pro_is_service_section_enable( $control ) && ( 'trip' == $content_type );
}

function travel_master_pro_is_service_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[service_content_type]' )->value();
	return travel_master_pro_is_service_section_enable( $control ) && ( 'trip-types' == $content_type );
}

function travel_master_pro_is_service_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[service_content_type]' )->value();
	return travel_master_pro_is_service_section_enable( $control ) && ( 'activity' == $content_type );
}

function travel_master_pro_is_service_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[service_content_type]' )->value();
	return travel_master_pro_is_service_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if video gallery section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_video_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_master_pro_theme_options[video_gallery_section_enable]' )->value() );
}

/**
 * Check if video gallery section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_video_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[video_gallery_content_type]' )->value();
	return travel_master_pro_is_video_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if video gallery section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_video_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[video_gallery_content_type]' )->value();
	return travel_master_pro_is_video_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_master_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[blog_content_type]' )->value();
	return travel_master_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[blog_content_type]' )->value();
	return travel_master_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[blog_content_type]' )->value();
	return travel_master_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[blog_content_type]' )->value();
	return travel_master_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

function travel_master_pro_is_blog_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[blog_content_type]' )->value();
	return travel_master_pro_is_blog_section_enable( $control ) && ( 'trip' == $content_type );
}

function travel_master_pro_is_blog_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[blog_content_type]' )->value();
	return travel_master_pro_is_blog_section_enable( $control ) && ( 'trip-types' == $content_type );
}

function travel_master_pro_is_blog_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[blog_content_type]' )->value();
	return travel_master_pro_is_blog_section_enable( $control ) && ( 'activity' == $content_type );
}

function travel_master_pro_is_blog_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[blog_content_type]' )->value();
	return travel_master_pro_is_blog_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if discover places section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_discover_places_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_master_pro_theme_options[discover_places_section_enable]' )->value() );
}

/**
 * Check if discover places section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_discover_places_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[discover_places_content_type]' )->value();
	return travel_master_pro_is_discover_places_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if discover places section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_discover_places_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[discover_places_content_type]' )->value();
	return travel_master_pro_is_discover_places_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if discover places section content type is trip.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_discover_places_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[discover_places_content_type]' )->value();
	return travel_master_pro_is_discover_places_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if discover places section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_discover_places_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[discover_places_content_type]' )->value();
	return travel_master_pro_is_discover_places_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if discover places section content type is trip types.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_discover_places_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[discover_places_content_type]' )->value();
	return travel_master_pro_is_discover_places_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if discover places section content type is destination.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_discover_places_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[discover_places_content_type]' )->value();
	return travel_master_pro_is_discover_places_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if discover places section content type is activity.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_discover_places_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[discover_places_content_type]' )->value();
	return travel_master_pro_is_discover_places_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_master_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[testimonial_content_type]' )->value();
	return travel_master_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[testimonial_content_type]' )->value();
	return travel_master_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[testimonial_content_type]' )->value();
	return travel_master_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[testimonial_content_type]' )->value();
	return travel_master_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if testimonial section content type is author.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_testimonial_section_content_author_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[testimonial_content_type]' )->value();
	return travel_master_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if subscription section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_master_pro_theme_options[subscription_section_enable]' )->value() );
}

/**
 * Check if video section is enabled.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_video_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travel_master_pro_theme_options[video_section_enable]' )->value() );
}

/**
 * Check if video section content type is post.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_video_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[video_content_type]' )->value();
	return travel_master_pro_is_video_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if video section content type is page.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_video_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[video_content_type]' )->value();
	return travel_master_pro_is_video_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if video section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_video_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travel_master_pro_theme_options[video_content_type]' )->value();
	return travel_master_pro_is_video_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if video section content type is category.
 *
 * @since Travel Master Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travel_master_pro_is_heading_tags_enable( $control ) {

	$tags = $control->manager->get_setting( 'travel_master_pro_theme_options[heading_tags]' )->value();
	return ($control->id == 'travel_master_pro_theme_options['.$tags.']');

}


