<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'travel_master_pro_about_section', array(
	'title'             => esc_html__( 'About Us','travel-master-pro' ),
	'description'       => esc_html__( 'About Us Section options.', 'travel-master-pro' ),
	'panel'             => 'travel_master_pro_front_page_panel',
) );

// About content enable control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'travel_master_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Master_Pro_Switch_Control( $wp_customize, 'travel_master_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_about_section',
	'on_off_label' 		=> travel_master_pro_switch_options(),
) ) );

// About content type control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'travel_master_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_master_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'travel-master-pro' ),
		'post' 		=> esc_html__( 'Post', 'travel-master-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'travel-master-pro' ),
	),
) );

// about sub title setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[about_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[about_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_about_section',
	'active_callback' 	=> 'travel_master_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_master_pro_theme_options[about_sub_title]', array(
		'selector'            => '#about-us .wrapper .entry-header p.section-subtitle',
		'settings'            => 'travel_master_pro_theme_options[about_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_master_pro_about_sub_title_partial',
    ) );
}

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'travel_master_pro_sanitize_page',
) );

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_about_section',
	'choices'			=> travel_master_pro_page_choices(),
	'active_callback'	=> 'travel_master_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'travel_master_pro_sanitize_page',
) );

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_about_section',
	'choices'			=> travel_master_pro_post_choices(),
	'active_callback'	=> 'travel_master_pro_is_about_section_content_post_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_about_section',
	'active_callback' 	=> 'travel_master_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_master_pro_theme_options[about_title]', array(
		'selector'            => '#about-us .wrapper .entry-header h2.section-title',
		'settings'            => 'travel_master_pro_theme_options[about_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_master_pro_about_title_partial',
    ) );
}

// about description setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[about_description]', array(
	'label'           	=> esc_html__( 'Description', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_about_section',
	'active_callback' 	=> 'travel_master_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_master_pro_theme_options[about_description]', array(
		'selector'            => '#about-us .wrapper .section-content p',
		'settings'            => 'travel_master_pro_theme_options[about_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_master_pro_about_description_partial',
    ) );
}

// about btn title setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_about_section',
	'active_callback' 	=> 'travel_master_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_master_pro_theme_options[about_btn_title]', array(
		'selector'            => '#about-us .wrapper .read-more a',
		'settings'            => 'travel_master_pro_theme_options[about_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_master_pro_about_btn_title_partial',
    ) );
}

// about btn link setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[about_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[about_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_about_section',
	'active_callback' 	=> 'travel_master_pro_is_about_section_content_custom_enable',
	'type'				=> 'url',
) );

// about image setting and control.
$wp_customize->add_setting( 'travel_master_pro_theme_options[about_image]', array(
	'sanitize_callback' => 'travel_master_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travel_master_pro_theme_options[about_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'travel-master-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'travel-master-pro' ), 650, 700 ),
		'section'     		=> 'travel_master_pro_about_section',
		'active_callback'	=> 'travel_master_pro_is_about_section_content_custom_enable',
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_master_pro_theme_options[about_content_destination]', array(
	'sanitize_callback' => 'travel_master_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Category_Control( $wp_customize,'travel_master_pro_theme_options[about_content_destination]', array(
	'label'             => esc_html__( 'Select Multiple Destinations', 'travel-master-pro' ),
	'description'      	=> esc_html__( 'Note: Press CTRL and select multiple destinations.', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_about_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'travel_master_pro_is_about_section_content_destination_enable'
) ) );

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[about_btn_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[about_btn_color]',
		array(
			'section'		=> 'travel_master_pro_about_section',
			'label'			=> esc_html__( 'Btn Color', 'travel-master-pro' ),

		)
	)
);

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[about_btn_hover_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[about_btn_hover_color]',
		array(
			'section'		=> 'travel_master_pro_about_section',
			'label'			=> esc_html__( 'Btn Hover Color', 'travel-master-pro' ),

		)
	)
); 

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[about_btn_text_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[about_btn_text_color]',
		array(
			'section'		=> 'travel_master_pro_about_section',
			'label'			=> esc_html__( 'Btn Text Color', 'travel-master-pro' ),

		)
	)
);

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[about_btn_text_hover_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[about_btn_text_hover_color]',
		array(
			'section'		=> 'travel_master_pro_about_section',
			'label'			=> esc_html__( 'Btn Text Hover Color', 'travel-master-pro' ),

		)
	)
); 

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[about_btn_border_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[about_btn_border_color]',
		array(
			'section'		=> 'travel_master_pro_about_section',
			'label'			=> esc_html__( 'Btn Border Color', 'travel-master-pro' ),

		)
	)
);

$wp_customize->add_setting(	
	'travel_master_pro_theme_options[about_btn_border_hover_color]',
	array(
		'sanitize_callback' => 'sanitize_hex_color',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'travel_master_pro_theme_options[about_btn_border_hover_color]',
		array(
			'section'		=> 'travel_master_pro_about_section',
			'label'			=> esc_html__( 'Btn Border Hover Color', 'travel-master-pro' ),

		)
	)
); 