<?php
/**
 * project section
 *
 * This is the template for the content of project section
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */
if ( ! function_exists( 'travel_master_pro_add_project_section' ) ) :
    /**
    * Add project section
    *
    *@since Travel Master Pro 1.0.0
    */
    function travel_master_pro_add_project_section() {
        $options = travel_master_pro_get_theme_options();
        // Check if project is enabled on frontpage
        $project_enable = apply_filters( 'travel_master_pro_section_status', true, 'project_section_enable' );

        if ( true !== $project_enable ) {
            return false;
        }

        // Render project section now.
        travel_master_pro_render_project_section( );
    }
endif;
        

if ( ! function_exists( 'travel_master_pro_render_project_section' ) ) :
  /**
   * Start project section
   *
   * @return string project content
   * @since Travel Master Pro 1.0.0
   *
   */
   function travel_master_pro_render_project_section( ) {
    $options = travel_master_pro_get_theme_options();
    if ( empty( $options['project_content_category'] ) ) {
        return;
    }
    ?>
    <div id="our-gallery" class="relative page-section">
        <div class="wrapper">
            <div class="section-header">
                <h2 class="section-title">
                    <?php echo esc_html( $options['project_title'] ); ?>
                </h2>
            </div>
            <ul class="tabs">
                <?php $i = 1; foreach ($options['project_content_category'] as $cat) { ?>
                    <li class="<?php echo $i == 1 ? 'active' : '' ?>" data-tab="<?php echo esc_attr($cat); ?>"><?php echo esc_html( get_the_category_by_ID($cat) ) ?></li>
                <?php $i++; } ?>
            </ul>
            <div class="section-content gallery-popup">
                <?php $i = 1; foreach ($options['project_content_category'] as $cat) { ?>
                    <div id="<?php echo esc_attr($cat); ?>" class="tab-content <?php echo $i == 1 ? 'active' : '' ?> grid">
                        <?php 
                            $args = array(
                                'post_type'         => 'post',
                                'cat'               => absint( $cat ),
                                'ignore_sticky_posts'   => true,
                                );

                            $query = new WP_Query( $args );
                            if ( $query->have_posts() ) : 
                                while ( $query->have_posts() ) : $query->the_post();
                        ?>
                                <article class="grid-item">
                                    <div class="gallery-item-wrapper">
                                        <div class="gallery-overlay">
                                            <div class="overlay-bg"></div>
                                        </div><!-- .gallery-overlay -->

                                        <div class="featured-image" style="background-image: url('<?php the_post_thumbnail_url( ) ; ?>');"></div>

                                        <a href="<?php the_post_thumbnail_url('large-size') ; ?>" class="popup"><i class="fa fa-plus"></i></a>

                                        <div class="entry-container">
                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php the_permalink( ); ?>"><?php the_title() ; ?></a></h2>
                                            </header>

                                            <span class="cat-links">
                                                <?php the_category( '', '' ) ?>      
                                            </span><!-- .cat-links -->
                                        </div><!-- .entry-container -->
                                    </div><!-- .gallery-item -->
                                </article>
                        <?php
                                endwhile;
                            endif;
                            wp_reset_postdata();
                        ?>
                    </div>
                <?php $i++; } ?>
            </div>
            <?php if ( !empty($options['project_btn_link']) && !empty($options['project_btn_title'])  ): ?>
                <div class="read-more">
                    <a href="<?php echo esc_url( $options['project_btn_link'] ) ; ?>" class="btn"><?php echo esc_html( $options['project_btn_title'] ) ; ?></a>
                </div><!-- .read-more -->
            <?php endif ?>
        </div><!-- .wrapper -->
    </div><!-- #our-gallery -->
    <?php   } 

endif;

