<?php
/**
 * video section
 *
 * This is the template for the content of video section
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */
if ( ! function_exists( 'travel_master_pro_add_video_section' ) ) :
    /**
    * Add video section
    *
    *@since Travel Master Pro 1.0.0
    */
    function travel_master_pro_add_video_section() {
    	$options = travel_master_pro_get_theme_options();
        // Check if video is enabled on frontpage
        $video_enable = apply_filters( 'travel_master_pro_section_status', true, 'video_section_enable' );

        if ( true !== $video_enable ) {
            return false;
        }
        // Get video section details
        $section_details = array();
        $section_details = apply_filters( 'travel_master_pro_filter_video_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render video section now.
        travel_master_pro_render_video_section( $section_details );
    }
endif;

if ( ! function_exists( 'travel_master_pro_get_video_section_details' ) ) :
    /**
    * video section details.
    *
    * @since Travel Master Pro 1.0.0
    * @param array $input video section details.
    */
    function travel_master_pro_get_video_section_details( $input ) {
        $options = travel_master_pro_get_theme_options();

        // Content type.
        $video_content_type  = $options['video_content_type'];
        $video_count = ! empty( $options['video_count'] ) ? $options['video_count'] : 4;
        
        $content = array();
        switch ( $video_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $video_count; $i++ ) {
                    if ( ! empty( $options['video_content_page_' . $i] ) )
                        $page_ids[] = $options['video_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $video_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $video_count; $i++ ) {
                    if ( ! empty( $options['video_content_post_' . $i] ) )
                        $post_ids[] = $options['video_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $video_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['video_content_category'] ) ? $options['video_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $video_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : ''; 

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// video section content details.
add_filter( 'travel_master_pro_filter_video_section_details', 'travel_master_pro_get_video_section_details' );


if ( ! function_exists( 'travel_master_pro_render_video_section' ) ) :
  /**
   * Start video section
   *
   * @return string video content
   * @since Travel Master Pro 1.0.0
   *
   */
   function travel_master_pro_render_video_section( $content_details = array() ) {
        $options = travel_master_pro_get_theme_options();
        $video_content_type  = $options['video_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="our-videos" class="relative page-section">
            <div class="wrapper">
                <div class="section-header">
                    <h2 class="section-title">
                        <?php echo esc_html( $options['video_title'] ) ; ?>
                    </h2>
                </div><!-- .section-header -->

                <div class="section-content grid">
                    <?php $i=1; foreach ($content_details as $content): ?>
                        <article class="grid-item">
                            <div class="video-item-wrapper">
                                <div class="video-overlay">
                                    <div class="overlay-bg"></div>
                                </div><!-- .video-overlay -->

                                <div class="featured-image" style="background-image: url(<?php echo esc_url( $content['image'] ) ; ?>)">
                                </div><!-- .featured-image -->
                                <?php if ( !empty($options['video_url_'.$i]) ): ?>
                                    <a href="<?php echo esc_url( $options['video_url_'.$i] ) ?>" class="video-popup">
                                        <svg viewBox="0 0 320.001 320.001">
                                            <path d="M295.84,146.049l-256-144c-4.96-2.784-11.008-2.72-15.904,0.128C19.008,5.057,16,10.305,16,16.001v288
                                            c0,5.696,3.008,10.944,7.936,13.824c2.496,1.44,5.28,2.176,8.064,2.176c2.688,0,5.408-0.672,7.84-2.048l256-144
                                            c5.024-2.848,8.16-8.16,8.16-13.952S300.864,148.897,295.84,146.049z"/>
                                        </svg>
                                    </a>
                                <?php endif ?>
                               

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <?php if ( !empty($options['video_sub_title_'.$i]) ): ?>
                                            <p class="subtitle"><?php echo esc_html( $options['video_sub_title_'.$i] ) ?></p>
                                        <?php endif ?>
                                        
                                        <h2 class="entry-title">
                                            <a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a>
                                        </h2>
                                    </header>
                                </div><!-- .entry-container -->
                            </div><!-- .video-item-wrapper -->
                        </article>
                    <?php $i++; endforeach ?>
                </div><!-- .section-content -->
                <?php if ( !empty($options['video_btn_url']) && !empty($options['video_btn_title']) ): ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['video_btn_url'] ) ; ?>" class="btn"> <?php echo esc_html( $options['video_btn_title'] ) ; ?></a>
                    </div><!-- .read-more -->
                <?php endif ?>
                
            </div><!-- .wrapper -->
        </div><!-- #our-videos -->

    <?php }
endif;